@@ -127,72 +127,60 @@ class MockArtifact
 
     public String getId()
     {
-        // TODO
         return null;
     }
 
     public String getDependencyConflictId()
     {
-        // TODO
         return null;
     }
 
     public void addMetadata( ArtifactMetadata artifactMetadata )
     {
-        // TODO
     }
 
     public ArtifactMetadata getMetadata( Class<?> metadataClass )
     {
-        // TODO
         return null;
     }
 
     public Collection<ArtifactMetadata> getMetadataList()
     {
-        // TODO
         return null;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void setRepository( ArtifactRepository artifactRepository )
     {
         //To change body of implemented methods use File | Settings | File Templates.
-        // TODO
     }
 
     public ArtifactRepository getRepository()
     {
-        // TODO
         return null;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void updateVersion( String string, ArtifactRepository artifactRepository )
     {
         //To change body of implemented methods use File | Settings | File Templates.
-        // TODO
     }
 
     public String getDownloadUrl()
     {
-        // TODO
         return null;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void setDownloadUrl( String string )
     {
         //To change body of implemented methods use File | Settings | File Templates.
-        // TODO
     }
 
     public ArtifactFilter getDependencyFilter()
     {
-        // TODO
         return null;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void setDependencyFilter( ArtifactFilter artifactFilter )
     {
-        // TODO
         //To change body of implemented methods use File | Settings | File Templates.
     }
 
@@ -203,14 +191,12 @@ class MockArtifact
 
     public List<String> getDependencyTrail()
     {
-        // TODO
         return null;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void setDependencyTrail( List<String> list )
     {
         //To change body of implemented methods use File | Settings | File Templates.
-        // TODO
     }
 
     public VersionRange getVersionRange()
@@ -220,13 +206,11 @@ class MockArtifact
 
     public void setVersionRange( VersionRange versionRange )
     {
-        // TODO
         //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void selectVersion( String string )
     {
-        // TODO
         //To change body of implemented methods use File | Settings | File Templates.
     }
 
@@ -237,19 +221,16 @@ class MockArtifact
 
     public void setResolved( boolean b )
     {
-        // TODO
         //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public boolean isResolved()
     {
-        // TODO
         return false;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void setResolvedVersion( String string )
     {
-        // TODO
         //To change body of implemented methods use File | Settings | File Templates.
     }
 
@@ -260,52 +241,44 @@ class MockArtifact
 
     public boolean isRelease()
     {
-        // TODO
         return false;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void setRelease( boolean b )
     {
-        // TODO
         //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public List<ArtifactVersion> getAvailableVersions()
     {
-        // TODO
         return null;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public void setAvailableVersions( List<ArtifactVersion> list )
     {
-        // TODO
         //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public boolean isOptional()
     {
         return false;  //To change body of implemented methods use File | Settings | File Templates.
-        // TODO
     }
 
     public void setOptional( boolean b )
     {
-        // TODO
         //To change body of implemented methods use File | Settings | File Templates.
     }
 
     public ArtifactVersion getSelectedVersion()
         throws OverConstrainedVersionException
     {
-        // TODO
-        return null;  //To change body of implemented methods use File | Settings | File Templates.
+        return VersionRange.createFromVersion( version ).getSelectedVersion( this );
     }
 
     public boolean isSelectedVersionKnown()
         throws OverConstrainedVersionException
     {
-        return false;  //To change body of implemented methods use File | Settings | File Templates.
-        // TODO
+        return VersionRange.createFromVersion( version ).isSelectedVersionKnown( this );
     }
 
     public void setGroupId( String groupId )
@@ -335,7 +308,6 @@ class MockArtifact
 
     public int compareTo( Artifact o )
     {
-        // TODO
         return 0;  //To change body of implemented methods use File | Settings | File Templates.
     }
 }
